/*
 * COPYRIGHT: FREQUENTIS AG. All rights reserved.
 *            Registered with Commercial Court Vienna,
 *            reg.no. FN 72.115b.
 */
package com.frequentis.ps.xap.lease;

import com.j_spaces.core.IJSpace;
import java.time.Duration;
import org.openspaces.core.GigaSpace;
import org.openspaces.core.GigaSpaceConfigurer;
import org.openspaces.core.space.UrlSpaceConfigurer;

/**
 * Start after PU has successfully started up.
 * Keep it running.
 */
public class ExternalActionTrigger {
    private static final Duration ACTION_WAIT_PERIOD = Duration.ofSeconds(5);
    private static final Duration LEASE_TIME = Duration.ofSeconds(3);

    public static void main(String[] args) throws InterruptedException {
        GigaSpace space = connect();

        // lets get to work
        for (int sequenceNr = 0; sequenceNr < Integer.MAX_VALUE; ++sequenceNr) {
            // poor mans solution
            Thread.sleep(ACTION_WAIT_PERIOD.toMillis());

            System.out.println("*** Writing instance #" + sequenceNr);

            ExpirationObject action = ExpirationObject.newInstance(sequenceNr);
            action.setSequenceNumber(sequenceNr);
            space.write(action, LEASE_TIME.toMillis());
        }
    }

    private static GigaSpace connect() {
        UrlSpaceConfigurer spaceConfigurer = new UrlSpaceConfigurer("jini://*/*/leaseExpiration")
                .lookupLocators("localhost");

        IJSpace javaSpace = spaceConfigurer.space();
        return new GigaSpaceConfigurer(javaSpace).clustered(true).gigaSpace();
    }
}